==> kubernetes-mock-1.3.53-sources.jar: io/fabric8/kubernetes/client/mock/impl/donable/MockDoneableSecret.java <==
/**
 * Copyright (C) 2015 Red Hat, Inc.                                        
 *                                                                         
 * Licensed under the Apache License, Version 2.0 (the "License");         
 * you may not use this file except in compliance with the License.        
 * You may obtain a copy of the License at                                 
 *                                                                         
 *         http://www.apache.org/licenses/LICENSE-2.0                      
 *                                                                         
 * Unless required by applicable law or agreed to in writing, software     
 * distributed under the License is distributed on an "AS IS" BASIS,       
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and     
 * limitations under the License.
 */

package io.fabric8.kubernetes.client.mock.impl.donable;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.DoneableSecret;
import io.fabric8.kubernetes.api.model.Secret;
import io.fabric8.kubernetes.api.model.SecretFluent;
import io.fabric8.kubernetes.api.model.Secret;
import io.fabric8.kubernetes.api.model.SecretFluent;
import io.fabric8.kubernetes.api.model.SecretFluentImpl;
import io.fabric8.kubernetes.client.mock.MockDoneable;
import org.easymock.EasyMock;
import org.easymock.IExpectationSetters;

public class MockDoneableSecret extends SecretFluentImpl<MockDoneableSecret> implements MockDoneable<Secret> {
  
  private interface DelegateInterface extends Doneable<Secret>, SecretFluent<DoneableSecret> {}
  private final Visitor<Secret> visitor = new Visitor<Secret>() {
    @Override
    public void visit(Secret pod) {
    }
  };

  private final DoneableSecret delegate;

  public MockDoneableSecret() {
    this.delegate = EasyMock.createMock(DoneableSecret .class);
  }

  @Override
  public IExpectationSetters<Secret> done() {
    return EasyMock.expect(delegate.done());
  }

  @Override
  public Void replay() {
    EasyMock.replay(delegate);
    return null;
  }

  @Override
  public void verify() {
    EasyMock.verify(delegate);
  }

  @Override
  public Doneable<Secret> getDelegate() {
    return new DoneableSecret(visitor) {
      @Override
      public Secret done() {
        return delegate.done();
      }
    };
  }
}

==> kubernetes-mock-1.3.97-sources.jar: io/fabric8/kubernetes/client/mock/impl/donable/MockDoneableSecret.java <==
/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.fabric8.kubernetes.client.mock.impl.donable;

import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.DoneableSecret;
import io.fabric8.kubernetes.api.model.Secret;
import io.fabric8.kubernetes.api.model.SecretBuilder;
import io.fabric8.kubernetes.api.model.SecretFluent;
import io.fabric8.kubernetes.api.model.SecretFluentImpl;
import io.fabric8.kubernetes.client.mock.MockDoneable;
import org.easymock.EasyMock;
import org.easymock.IExpectationSetters;

public class MockDoneableSecret extends SecretFluentImpl<MockDoneableSecret> implements MockDoneable<Secret> {

  private interface DelegateInterface extends Doneable<Secret>, SecretFluent<DoneableSecret> {}
  private final Function<Secret, Secret> visitor = new Function<Secret, Secret>() {
    @Override
    public Secret apply(Secret item) {return item;}
  };

  private final DelegateInterface delegate;

  public MockDoneableSecret() {
    super(new SecretBuilder()
      .withNewMetadata().endMetadata()
      .build());
    this.delegate = EasyMock.createMock(DelegateInterface .class);
  }

  @Override
  public IExpectationSetters<Secret> done() {
    return EasyMock.expect(delegate.done());
  }

  @Override
  public Void replay() {
    EasyMock.replay(delegate);
    return null;
  }

  @Override
  public void verify() {
    EasyMock.verify(delegate);
  }

  @Override
  public Doneable<Secret> getDelegate() {
    return new DoneableSecret(new SecretBuilder(this).build(), visitor) {
      @Override
      public Secret done() {
        return delegate.done();
      }
    };
  }
}
